@@ -15,6 +15,14 @@ type filterDocument struct {
 
 // Filter fires the filter event.
 func (root *Root) Filter(str string, nonMatch bool) {
+	go func() {
+		root.Doc.WaitEOFWithTimeout(root.Config.ReadWaitTime)
+		root.sendFilter(str, nonMatch)
+	}()
+}
+
+// sendFilter sends the filter event to the document.
+func (root *Root) sendFilter(str string, nonMatch bool) {
 	root.Doc.nonMatch = nonMatch
 	root.input.value = str
 	ev := &eventInputSearch{
@@ -40,7 +48,7 @@ func (root *Root) filterDocument(ctx context.Context, searcher Searcher) {
 	r, w := io.Pipe()
 	render, err := renderDoc(m, r)
 	if err != nil {
-		log.Println(err)
+		log.Printf("failed to filter document: %v\n", err)
 		return
 	}
 	render.documentType = DocFilter
@@ -51,22 +59,19 @@ func (root *Root) filterDocument(ctx context.Context, searcher Searcher) {
 	render.Caption = "filter:" + match
 	msg := "search:" + match
 	root.insertDocument(ctx, root.CurrentDoc, render)
-	render.general = mergeGeneral(root.Config.General, render.general)
+	render.RunTimeSettings = m.RunTimeSettings
 	render.regexpCompile()
 
-	render.nonMatch = m.nonMatch
-	render.Header = m.Header
-	render.SkipLines = m.SkipLines
 	filterDoc := &filterDocument{
 		Document: render,
 		w:        w,
 	}
 
 	// Copy the header
-	for ln := 0; ln < render.firstLine(); ln++ {
+	for ln := range render.firstLine() {
 		line, err := m.Line(ln)
 		if err != nil {
-			log.Println(err)
+			log.Printf("failed to get line %d: %v\n", ln, err)
 			break
 		}
 		render.lineNumMap.Store(ln, ln)
@@ -112,6 +117,8 @@ func (root *Root) closeAllFilter(ctx context.Context) {
 		return
 	}
 
+	// closeAllDocumentsOfType closes all documents of the specified type.
+	// It returns the document number to switch to and a list of closed document names.
 	docNum, closed := root.closeAllDocumentsOfType(DocFilter)
 	root.setDocumentNum(ctx, docNum)
 
@@ -121,14 +128,3 @@ func (root *Root) closeAllFilter(ctx context.Context) {
 	}
 	root.setMessageLogf("close %s", strings.Join(closed, ", "))
 }
-
-// writeLine writes a line to w.
-// It adds a newline to the end of the line.
-func writeLine(w io.Writer, line []byte) {
-	if _, err := w.Write(line); err != nil {
-		panic(err)
-	}
-	if _, err := w.Write([]byte("\n")); err != nil {
-		panic(err)
-	}
-}
