@@ -1,9 +1,12 @@
 package oviewer
 
 import (
+	"bytes"
 	"io"
 	"log"
+	"os"
 	"regexp"
+	"runtime"
 	"slices"
 	"strings"
 )
@@ -94,3 +97,40 @@ func writeLine(w io.Writer, line []byte) {
 		log.Printf("%s:%s", line, err)
 	}
 }
+
+// stripEscapeSequenceString removes escape sequences and backspaces from a string.
+// It is used to identify and remove these sequences from strings or byte slices.
+var stripRegexpES = regexp.MustCompile("(\x1b\\[[\\d;*]*m)|.\\x08")
+
+func stripEscapeSequenceString(src string) string {
+	if !strings.ContainsAny(src, "\x1b\\x08") {
+		return src
+	}
+	// Remove EscapeSequence.
+	return stripRegexpES.ReplaceAllString(src, "")
+}
+
+// stripEscapeSequence strips if it contains escape sequences.
+func stripEscapeSequenceBytes(src []byte) []byte {
+	if !bytes.ContainsAny(src, "\x1b\x08") {
+		return src
+	}
+	// Remove EscapeSequence.
+	return stripRegexpES.ReplaceAll(src, []byte(""))
+}
+
+// getShell returns the shell name based on the operating system.
+func getShell() string {
+	if runtime.GOOS == "windows" {
+		return "CMD.EXE"
+	}
+	return "/bin/sh"
+}
+
+// getTTY returns the TTY file based on the operating system.
+func getTTY() (*os.File, error) {
+	if runtime.GOOS == "windows" {
+		return os.Open("CONIN$")
+	}
+	return os.Open("/dev/tty")
+}
